@@ -49,7 +49,7 @@ def holster(app, route, **kwargs):
     """
 
     def inner(view):
-        wrapped = holsterize(app, view)
+        wrapped = holsterize(view)
         # This returns the wrapped view. We don't care about it though.
         bare_holster(app, route, **kwargs)(wrapped)
 
@@ -62,6 +62,15 @@ def holster(app, route, **kwargs):
 
 
 def holster_url_value_preprocessor(endpoint, values):
+    """
+    Figure out which MIME type should be returned, and prepare the value for
+    later processing.
+    """
+
+    # Check to see if this has already happened, e.g. in a blueprint.
+    if hasattr(g, "_holster_mime"):
+        return
+
     types = Accept(",".join(templates))
     if values and "ext" in values:
         ext = values.pop("ext")
@@ -71,12 +80,12 @@ def holster_url_value_preprocessor(endpoint, values):
 
     mime = accept.best(types)
 
-    g.mime = mime
+    g._holster_mime = mime
 
 
 def init_holster(app):
     """
-    Initialize a Flask to have holsters.
+    Initialize a Flask application or blueprint to have holsters.
 
     This is mostly just attaching hooks and setting default configuration
     values.
@@ -84,7 +93,8 @@ def init_holster(app):
 
     app.bare_holster = partial(bare_holster, app)
     app.holster = partial(holster, app)
-    app.holsterize = partial(holsterize, app)
+    app.holsterize = holsterize
     app.url_value_preprocessor(holster_url_value_preprocessor)
 
-    app.config.setdefault("HOLSTER_COMPRESS", False)
+    if hasattr(app, "config"):
+        app.config.setdefault("HOLSTER_COMPRESS", False)
